pub struct Theme {Show 31 fields
pub html_block_style: Style,
pub inline_html_style: Style,
pub code_style: Style,
pub link_style: Style,
pub image_link_style: Style,
pub rule_color: Color,
pub quote_border_style: Style,
pub h2_style: Style,
pub h2_marker: String,
pub h3_style: Style,
pub h3_marker: String,
pub h4_style: Style,
pub h4_marker: String,
pub h5_style: Style,
pub h5_marker: String,
pub h6_style: Style,
pub h6_marker: String,
pub footnote_style: Style,
pub math_style: Style,
pub alert_note_style: Style,
pub alert_note_label: String,
pub alert_tip_style: Style,
pub alert_tip_label: String,
pub alert_important_style: Style,
pub alert_important_label: String,
pub alert_warning_style: Style,
pub alert_warning_label: String,
pub alert_caution_style: Style,
pub alert_caution_label: String,
pub h1_prefix_style: Style,
pub h1_text_style: Style,
}Expand description
A colour theme for mdcat.
All fields are public so themes can be fully customised, e.g. from a user config file.
h1_prefix_style is a derived convenience (background-only padding matching h1_text_style’s
background); use Theme::with_h1 to keep the two in sync when changing the H1 background.
Fields
html_block_style: StyleStyle for HTML blocks.
inline_html_style: StyleStyle for inline HTML.
code_style: StyleStyle for code, unless the code is syntax-highlighted.
link_style: StyleStyle for links.
image_link_style: StyleColor for image links (unless the image is rendered inline)
rule_color: ColorColor for rulers.
quote_border_style: StyleStyle for block quote borders (│).
h2_style: StyleStyle for H2 headings.
h2_marker: StringMarker written before H2 heading text (default "━━ ").
h3_style: StyleStyle for H3 headings.
h3_marker: StringMarker written before H3 heading text (default "── ").
h4_style: StyleStyle for H4 headings.
h4_marker: StringMarker written before H4 heading text (default "┄ ").
h5_style: StyleStyle for H5 headings.
h5_marker: StringMarker written before H5 heading text (default "╌ ").
h6_style: StyleStyle for H6 headings.
h6_marker: StringMarker written before H6 heading text (default "· ").
footnote_style: StyleStyle for footnote references and definitions.
math_style: StyleStyle for math expressions.
alert_note_style: StyleStyle for [!NOTE] alerts.
alert_note_label: StringIcon and label written for [!NOTE] alerts (default "ℹ NOTE").
alert_tip_style: StyleStyle for [!TIP] alerts.
alert_tip_label: StringIcon and label written for [!TIP] alerts (default "◆ TIP").
alert_important_style: StyleStyle for [!IMPORTANT] alerts.
alert_important_label: StringIcon and label written for [!IMPORTANT] alerts (default "★ IMPORTANT").
alert_warning_style: StyleStyle for [!WARNING] alerts.
alert_warning_label: StringIcon and label written for [!WARNING] alerts (default "⚠ WARNING").
alert_caution_style: StyleStyle for [!CAUTION] alerts.
alert_caution_label: StringIcon and label written for [!CAUTION] alerts (default "✖ CAUTION").
h1_prefix_style: StyleBackground-colored padding space written before H1 text.
h1_text_style: StyleStyle for H1 heading text (fg + bg color).
Implementations
Sourceimpl Theme
impl Theme
Sourcepub fn catppuccin_mocha() -> Self
pub fn catppuccin_mocha() -> Self
Catppuccin Mocha (dark).
Sourcepub fn catppuccin_latte() -> Self
pub fn catppuccin_latte() -> Self
Catppuccin Latte (light).
Sourcepub fn gruvbox_dark() -> Self
pub fn gruvbox_dark() -> Self
Gruvbox Dark.
Sourcepub fn gruvbox_light() -> Self
pub fn gruvbox_light() -> Self
Gruvbox Light.
Sourcepub fn solarized_dark() -> Self
pub fn solarized_dark() -> Self
Solarized Dark.
Sourcepub fn solarized_light() -> Self
pub fn solarized_light() -> Self
Solarized Light.