pub struct TerminalSize {
pub columns: u16,
pub rows: u16,
pub pixels: Option<PixelSize>,
pub cell: Option<PixelSize>,
}Expand description
The size of a terminal.
Fields
columns: u16The width of the terminal, in characters aka columns.
rows: u16The height of the terminal, in lines.
pixels: Option<PixelSize>The size in pixels, if available.
cell: Option<PixelSize>The size of once cell, if available.
Implementations
Sourceimpl TerminalSize
impl TerminalSize
Sourcepub fn from_env() -> Option<Self>
pub fn from_env() -> Option<Self>
Get terminal size from $COLUMNS and $LINES.
Do not assume any knowledge about window size.
Sourcepub fn from_terminal() -> Option<Self>
pub fn from_terminal() -> Option<Self>
Detect the terminal size by querying the underlying terminal.
On unix this issues a ioctl to the controlling terminal.
On Windows this uses the terminal_size crate which does some magic windows API calls.
Sourcepub fn detect() -> Option<Self>
pub fn detect() -> Option<Self>
Detect the terminal size.
Get the terminal size from the underlying TTY, and fallback to
$COLUMNS and $LINES.
Sourcepub fn with_max_columns(&self, max_columns: u16) -> Self
pub fn with_max_columns(&self, max_columns: u16) -> Self
Shrink the terminal size to the given amount of maximum columns.
Also shrinks the pixel size accordingly.